@@ -27,7 +27,7 @@ use rdev::listen;
 use std::thread;
 
 /// Starts the typewriter.
-pub async fn run(sound_preset: SoundPreset, device: Option<String>) -> Result<()> {
+pub async fn run(sound_presets: Vec<SoundPreset>, device: Option<String>) -> Result<()> {
     // Create a listener for the keyboard events.
     let (sender, mut receiver) = tokio::sync::mpsc::unbounded_channel();
     thread::spawn(move || {
@@ -40,13 +40,18 @@ pub async fn run(sound_preset: SoundPreset, device: Option<String>) -> Result<()
     });
 
     // Create the application state.
-    tracing::debug!("{:#?}", sound_preset);
-    let mut app = App::init(sound_preset, device)?;
+    tracing::debug!("{:#?}", sound_presets);
+    let mut apps = sound_presets
+        .into_iter()
+        .map(|sound_preset| App::init(sound_preset, device.clone()))
+        .collect::<Result<Vec<_>>>()?;
 
     // Handle events.
     loop {
         if let Some(event) = receiver.recv().await {
-            app.handle_key_event(event)?;
+            for app in apps.iter_mut() {
+                app.handle_key_event(event.clone()).unwrap();
+            }
         }
     }
 }
